pub fn classify(data: &[u8]) -> FileFormatExpand description
Classify a file’s format from its header bytes.
Only needs the first ~64 bytes for most formats, but benefits from more data for DNG version detection (scans first 1KB for DNG tag).
pub fn classify(data: &[u8]) -> FileFormatClassify a file’s format from its header bytes.
Only needs the first ~64 bytes for most formats, but benefits from more data for DNG version detection (scans first 1KB for DNG tag).